@@ -2,9 +2,14 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * @package phpMyAdmin-Transformation
- * @version $Id$
  */
 
+function PMA_transformation_image_jpeg__link_info() {
+    return array(
+        'info' => __('Displays a link to download this image.'),
+        );
+}
+
 /**
  *
  */
