@@ -2,9 +2,14 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * @package phpMyAdmin-Transformation
- * @version $Id: image_png__inline.inc.php 11973 2008-11-24 09:30:37Z nijel $
  */
 
+function PMA_transformation_image_png__inline_info() {
+    return array(
+        'info' => __('Displays a clickable thumbnail. The options are the maximum width and height in pixels. The original aspect ratio is preserved.'),
+        );
+}
+
 /**
  *
  */
