@@ -1,7 +1,7 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- * this file is register_globals save
+ * this file is register_globals safe
  *
  * @todo    move JavaScript out of here into .js files
  * @uses    $cfg['QueryWindowDefTab']
@@ -12,34 +12,23 @@
  * @uses    $cfg['Confirm']
  * @uses    $GLOBALS['db']
  * @uses    $GLOBALS['table']
- * @uses    $GLOBALS['strSQL']
- * @uses    $GLOBALS['strImportFiles']
- * @uses    $GLOBALS['strQuerySQLHistory']
- * @uses    $GLOBALS['strAll']
- * @uses    $GLOBALS['strChange']
- * @uses    $GLOBALS['strFormEmpty']
- * @uses    $GLOBALS['strNotNumber']
- * @uses    $GLOBALS['strNoDropDatabases']
- * @uses    $GLOBALS['strDoYouReally']
- * @uses    $GLOBALS['strQuerySQLHistory']
  * @uses    PMA_isSuperuser()
  * @uses    PMA_outBufferPre()
  * @uses    PMA_getRelationsParam()
  * @uses    PMA_isValid()
  * @uses    PMA_ifSetOr()
- * @uses    PMA_setHistory()
  * @uses    PMA_getHistory()
  * @uses    PMA_generate_common_url()
  * @uses    PMA_generate_common_hidden_inputs()
  * @uses    PMA_escapeJsString()
- * @uses    PMA_getTabs()
+ * @uses    PMA_generate_html_tabs()
  * @uses    PMA_sqlQueryForm()
  * @uses    PMA_jsFormat()
  * @uses    in_array()
  * @uses    strlen()
  * @uses    preg_replace()
  * @uses    htmlspecialchars()
- * @version $Id: querywindow.php 10238 2007-04-01 09:26:14Z cybot_tm $
+ * @package phpMyAdmin
  */
 
 /**
@@ -61,9 +50,8 @@ require_once './libraries/ob.lib.php';
 PMA_outBufferPre();
 
 /**
- * load relations
+ * load relation params
  */
-require_once './libraries/relation.lib.php';
 $cfgRelation = PMA_getRelationsParam();
 
 /**
@@ -97,25 +85,25 @@ if ($no_js) {
 } else {
     $tabs = array();
     $tabs['sql']['icon']   = 'b_sql.png';
-    $tabs['sql']['text']   = $GLOBALS['strSQL'];
+    $tabs['sql']['text']   = __('SQL');
     $tabs['sql']['fragment']   = '#';
-    $tabs['sql']['attr']   = 'onclick="javascript:PMA_querywindowCommit(\'sql\');return false;"';
+    $tabs['sql']['attr']   = 'onclick="PMA_querywindowCommit(\'sql\');return false;"';
     $tabs['sql']['active'] = (bool) ($querydisplay_tab == 'sql');
     $tabs['import']['icon']   = 'b_import.png';
-    $tabs['import']['text']   = $GLOBALS['strImportFiles'];
+    $tabs['import']['text']   = __('Import files');
     $tabs['import']['fragment']   = '#';
-    $tabs['import']['attr']   = 'onclick="javascript:PMA_querywindowCommit(\'files\');return false;"';
+    $tabs['import']['attr']   = 'onclick="PMA_querywindowCommit(\'files\');return false;"';
     $tabs['import']['active'] = (bool) ($querydisplay_tab == 'files');
     $tabs['history']['icon']   = 'b_bookmark.png';
-    $tabs['history']['text']   = $GLOBALS['strQuerySQLHistory'];
+    $tabs['history']['text']   = __('SQL history'); 
     $tabs['history']['fragment']   = '#';
-    $tabs['history']['attr']   = 'onclick="javascript:PMA_querywindowCommit(\'history\');return false;"';
+    $tabs['history']['attr']   = 'onclick="PMA_querywindowCommit(\'history\');return false;"';
     $tabs['history']['active'] = (bool) ($querydisplay_tab == 'history');
 
     if ($GLOBALS['cfg']['QueryWindowDefTab'] == 'full') {
-        $tabs['all']['text']   = $GLOBALS['strAll'];
+        $tabs['all']['text']   = __('All');
         $tabs['all']['fragment']   = '#';
-        $tabs['all']['attr']   = 'onclick="javascript:PMA_querywindowCommit(\'full\');return false;"';
+        $tabs['all']['attr']   = 'onclick="PMA_querywindowCommit(\'full\');return false;"';
         $tabs['all']['active'] = (bool) ($querydisplay_tab == 'full');
     }
 }
@@ -123,14 +111,14 @@ if ($no_js) {
 if ($GLOBALS['cfg']['PropertiesIconic']) {
     $titles['Change'] =
          '<img class="icon" width="16" height="16" src="' . $pmaThemeImage
-        . 'b_edit.png" alt="' . $GLOBALS['strChange'] . '" title="' . $GLOBALS['strChange']
+        . 'b_edit.png" alt="' . __('Change') . '" title="' . __('Change')
         . '" />';
 
     if ('both' === $GLOBALS['cfg']['PropertiesIconic']) {
-        $titles['Change'] .= $GLOBALS['strChange'];
+        $titles['Change'] .= __('Change') . ' ';
     }
 } else {
-    $titles['Change'] = $GLOBALS['strChange'];
+    $titles['Change'] = __('Change') . ' ';
 }
 
 $url_query = PMA_generate_common_url($db, $table);
@@ -163,78 +151,46 @@ if (! empty($show_query)) {
 $sql_query = '';
 
 /**
- * start HTML output
+ * prepare JavaScript functionality
+ */
+$js_include[] = 'common.js';
+$js_include[] = 'querywindow.js';
+
+if (PMA_isValid($_REQUEST['auto_commit'], 'identical', 'true')) {
+    $js_events[] = array(
+        'event'     => 'load',
+        'function'  => 'PMA_queryAutoCommit',
+    );
+}
+if (PMA_isValid($_REQUEST['init'])) {
+    $js_events[] = array(
+        'event'     => 'load',
+        'function'  => 'PMA_querywindowResize',
+    );
+}
+// always set focus to the textarea
+if ($querydisplay_tab == 'sql' || $querydisplay_tab == 'full') {
+    $js_events[] = array(
+        'event'     => 'load',
+        'function'  => 'PMA_querywindowSetFocus',
+    );
+}
+
+/**
+ * start HTTP/HTML output
  */
 require_once './libraries/header_http.inc.php';
 require_once './libraries/header_meta_style.inc.php';
+require_once './libraries/header_scripts.inc.php';
 ?>
-<script type="text/javascript">
-//<![CDATA[
-var errorMsg0   = '<?php echo PMA_escapeJsString($GLOBALS['strFormEmpty']); ?>';
-var errorMsg1   = '<?php echo PMA_escapeJsString($GLOBALS['strNotNumber']); ?>';
-var noDropDbMsg = '<?php echo (!$is_superuser && !$GLOBALS['cfg']['AllowUserDropDatabase'])
-    ? PMA_escapeJsString($GLOBALS['strNoDropDatabases']) : ''; ?>';
-var confirmMsg  = '<?php echo $GLOBALS['cfg']['Confirm']
-    ? PMA_escapeJsString($GLOBALS['strDoYouReally']) : ''; ?>';
-
-function PMA_queryAutoCommit() {
-    document.getElementById('sqlqueryform').target = window.opener.frame_content.name;
-    document.getElementById('sqlqueryform').submit();
-    return;
-}
-
-function PMA_querywindowCommit(tab) {
-    document.getElementById('hiddenqueryform').querydisplay_tab.value = tab;
-    document.getElementById('hiddenqueryform').submit();
-    return false;
-}
-
-function PMA_querywindowResize() {
-    // for Gecko
-    if (typeof(self.sizeToContent) == 'function') {
-        self.sizeToContent();
-        //self.scrollbars.visible = false;
-        // give some more space ... to prevent 'fli(pp/ck)ing'
-        self.resizeBy(10, 50);
-        return;
-    }
-
-    // for IE, Opera
-    if (document.getElementById && typeof(document.getElementById('querywindowcontainer')) != 'undefined') {
-
-        // get content size
-        var newWidth  = document.getElementById('querywindowcontainer').offsetWidth;
-        var newHeight = document.getElementById('querywindowcontainer').offsetHeight;
-
-        // set size to contentsize
-        // plus some offset for scrollbars, borders, statusbar, menus ...
-        self.resizeTo(newWidth + 45, newHeight + 75);
-    }
-}
-
-function PMA_querywindowInit()
-{
-<?php
-if (PMA_isValid($_REQUEST['auto_commit'], 'identical', 'true')) {
-    echo 'PMA_queryAutoCommit();' . "\n";
-}
-if (PMA_isValid($_REQUEST['init'])) {
-    echo 'PMA_querywindowResize();' . "\n";
-}
-?>
-}
-
-//]]>
-</script>
-<script src="./js/functions.js" type="text/javascript"></script>
 </head>
 
-<body id="bodyquerywindow" onload="PMA_querywindowInit();">
+<body id="bodyquerywindow">
 <div id="querywindowcontainer">
 <?php
 
 if ($tabs) {
-    echo PMA_getTabs($tabs);
+    echo PMA_generate_html_tabs($tabs, array());
     unset($tabs);
 }
 
@@ -246,8 +202,8 @@ $_sql_history = PMA_getHistory($GLOBALS['cfg']['Server']['user']);
 if (! empty($_sql_history)
  && ($querydisplay_tab == 'history' || $querydisplay_tab == 'full')) {
     $tab = $querydisplay_tab != 'full' ? 'sql' : 'full';
-    echo $GLOBALS['strQuerySQLHistory'] . ':<br />' . "\n"
-        .'<ul>';
+    echo __('SQL history') . ':<br />'
+        . '<ul>';
     foreach ($_sql_history as $query) {
         echo '<li>' . "\n";
 
@@ -300,15 +256,3 @@ if (! empty($_sql_history)
 </div>
 </body>
 </html>
-
-<?php
-/**
- * Close MySql connections
- */
-if (! empty($controllink)) {
-    PMA_DBI_close($controllink);
-}
-if (! empty($userlink)) {
-    PMA_DBI_close($userlink);
-}
-?>
